"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v0.0.1-alpha.121
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_client
from ory_client.model.ui_text import UiText
globals()['UiText'] = UiText
from ory_client.model.ui_node_text_attributes import UiNodeTextAttributes


class TestUiNodeTextAttributes(unittest.TestCase):
    """UiNodeTextAttributes unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUiNodeTextAttributes(self):
        """Test UiNodeTextAttributes"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UiNodeTextAttributes()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
